@@ -42,7 +42,7 @@ class Kart:
             "timezone": "UTC",
             "serving": False,
         }
-        merge_dicts(self.config, default)
+        self.config = merge_dicts(self.config, default)
 
     def mine_data(self, start: bool = True):
         """Calls miners and content modifiers"""
@@ -50,7 +50,7 @@ class Kart:
         for miner in self.miners:
             if start:
                 miner.read_data(self.config)
-            self.site.update(miner.collect(self.config))
+            self.site = merge_dicts(self.site, miner.collect(self.config))
         for modifier in self.content_modifiers:
             modifier.modify(self.config, self.site)
 
@@ -161,18 +161,20 @@ class Kart:
             "-p", "--port", help="port to bind to", default=9000, type=int
         )
         parser.add_argument(
-            "--dev-url",
-            help="serve your site on a different url",
+            "--url",
+            help="specify website url",
             type=str,
         )
         args = parser.parse_args()
-        if args.command == "build":
-            self.config["serving"] = False
-            self.build()
+
+        self.config["serving"] = False
         if args.command == "serve":
             self.config["serving"] = True
-            if args.dev_url:
-                self.config["site_url"] = args.dev_url
-            else:
-                self.config["site_url"] = f"http://localhost:{args.port}"
+            self.config["site_url"] = f"http://localhost:{args.port}"
+        if args.url:
+            self.config["site_url"] = args.url
+
+        if args.command == "build":
+            self.build()
+        if args.command == "serve":
             self.serve(args.port)
