@@ -22,7 +22,7 @@ class KartObserver(Observer):
         """Ovverrides Observer.run() to execute an function each time an even is handled"""
         while self.should_keep_running():
             try:
-                self.dispatch_events(self.event_queue, self.timeout)
+                self.dispatch_events(self.event_queue)
                 if self.event_queue.empty():
                     self.action()
             except queue.Empty:
@@ -129,12 +129,24 @@ def id_from_path(base_dir: Path, path: Path) -> str:
 
 def merge_dicts(a: dict, b: dict) -> dict:
     """Merge two dicts"""
-    for key in b:
+    c = a.__class__()
+    for key in a.keys():
+        c[key] = a[key]
+    for key in b.keys():
         if key not in a:
-            a[key] = b[key]
+            c[key] = b[key]
         else:
             if isinstance(b[key], dict):
                 if isinstance(a[key], dict):
-                    merge_dicts(a[key], b[key])
+                    c[key] = merge_dicts(a[key], b[key])
                 else:
                     raise Exception
+    return c
+
+
+def str_to_bool(x: str) -> bool:
+    if x in ("y", "yes", "t", "true", "on", "1"):
+        return True
+    if x in ("n", "no", "f", "false", "off", "0"):
+        return False
+    raise ValueError()
